% exampleACALOS_cfg - example measurement configuration file -
%
% This matlab skript is called by afc_main when starting
% the experiment 'exampleACALOS'.
% exampleACALOS_cfg constructs a structure 'def' containing the complete
% configuration for the experiment.
% To design an own experiment, e.g., 'myexperiment'
% make changes in this file and save it as 'myexperiment_cfg.m'.
% The default values of all parameters are defined in 'default_cfg.m'
%
% See also help exampleACALOS_set, exampleACALOS_user, afc_main
%
% Copyright (c) 1999-2013 Stephan Ewert, Universitaet Oldenburg.
%                         Dirk Oetting, Fraunhofer IDMT
% $Revision: 1.40 beta$  $Date: 25.01.2013 10:47 $


% general measurement procedure
def.measurementProcedure = 'ACALOS';	% measurement procedure
def.intervalnum = 1;				% number of intervals
def.repeatnum = 1;                  % number of repeatitions of the experiment

% measurement
def.modelEnable = 0;
def.afcwinEnable = 1;
def.soundEnable = 1;

% addional signal information in command window (0: off, 1: on)
def.debug = 0;  

% tracking variable (dependent variable)
% starting level of 65 dB according to ISO 16832
def.startvar = 65;                  % starting value of the tracking variable

def.expvarunit = 'dB HL';           % unit of the tracking variable
def.expvardescription = 'Level';    % description of the tracking variable
def.samplerate = 44100;				% sampling rate in Hz
def.intervallen = 1*def.samplerate; % signal duration in samples (default 1s)

def.ACALOS_randomizeRangeEstimation = 1; % 0: alternating up down track, 1: randomize up- down track
def.ACALOS_levelRounding = 1;         % round level in 0.1 dB steps

% limits for tracking variable
def.minvar = -10;				% minimum value of the tracking variable
def.maxvar = 105;				% maximum value of the tracking variable (narrow band: dB HL)

% only warning when stimulus is clipping
def.checkOutputClip = 1;

% experimental variable (independent variable)
def.exppar1 = [250 500 1000 2000 4000 6000]';  % signal centerf, column vector as interleaved is activated
def.exppar1unit = 'Hz';                         % unit of experimental parameter
def.exppar1description = 'Centre frequency';          % description of the experimental parameter


def.interleaved = 1;                            % toggles block interleaving on (1), off (0)
def.interleavenum = size(def.exppar1,1); 		% number of interleaved runs


% The experiment uses multiple exppars (exppar1 ... exppar3).
% def.parrand has 1 elements for 1 exppars.
def.parrand = [0];

% interface, feedback and messages
def.afcwin = 'ACALOS_win';          % overload response window
def.windetail = 1;					% displays additional information in the response window
def.mouse = 1;						% enables mouse/touch screen control (1), or disables (0)
def.feedback = 0;					% no feedback
def.messages = 'ACALOS';			% message configuration file, if 'autoSelect' AFC automatically selects depending on expname and language setting, fallback is 'default'. If 'default' or any arbitrary string, the respectively named _msg file is used.
def.language = 'EN';				% EN = english, DE = german, FR = french, DA = danish
def.soundmexMark = 0;				% disable all button marking
def.markinterval = 0;				% disable all button marking
def.winButtonConfiguration = 0;     % show start and end button
def.winFigurePosition = [600 100 900 600];

% save paths and save function
def.result_path = 'sessions/';				% where to save results
def.control_path = 'sessions/';		% where to save control files
def.savefcn = 'default';			% function which writes results to disk

% samplerate, number of channels and sound output
% def.deviceID = 0;
% def.bits = 32;						% output bit depth: 8 or 16 see def.externSoundCommand for 32 bits
% def.externSoundCommand = 'soundmexprofree';        % this experiment can also use soundmexpro

% computing
def.allowpredict = 0;

def.showEnable = 0;
def.showrun = 1;
def.showtrial = 0;
def.showstimuli = 0;

% 
def.variableCheck = 1;

% eof
