% exampleACALOS_set - setup function of experiment 'exampleACALOS' -
%
% This function is called by afc_main when starting
% the experiment 'exampleACALOS'. It defines elements
% of the structure 'setup'. The elements of 'setup' are used
% by the function 'exampleACALOS_user.m'.
%
% If an experiments can be started with different experimental
% conditions, e.g, presentation at different sound preasure levels,
% one might switch between different condition dependent elements
% of structure 'setup' here.
%
% For most experiments it is also suitable to pregenerate some
% stimuli here.
%
% To design an own experiment, e.g., 'myexperiment',
% make changes in this file and save it as 'myexperiment_set.m'.
% Ensure that this function does exist, even if absolutely nothing
% is done here.
%
% See also help exampleACALOS_cfg, exampleACALOS_user, afc_main
%
% Copyright (c) 1999-2013 Stephan Ewert, Universitaet Oldenburg.
%                         Dirk Oetting, Fraunhofer IDMT
% $Revision: 1.30 beta$  $Date: 26.05.2014 $

function exampleACALOS_set

global def
global work
global setup


% calibration flag
% this flag indicates calibration procedure (=1) where the signals are
% presented at 80 dB SPL(CC)
% 0 = normal measurement mode
% 1 = calibration mode
% 2 = check for the current calibration, at which level the narrow-band signal 
% starts clipping
setup.calib = 0;                  


% calibration values for [left right] channel for 1 kHz. After calibration
% the signal level is 80 dB SPL(CC) measured with the Sennheiser HDA200 
% and the B+K artificial ear (see addon_ACALOS_readme.txt "Calibration") 
setup.calib_1kHz = [110 110];

% to transform from dB HL to dB SPL(CC) for HDA200 (ISO 389-8)
% for 250, 500, 1k, 2k, 4k, 6k, 8k Hz
setup.RETSPL = [18   11  5.5  4.5   9.5    17  17.5];

% to transform from dB SPL(CC) to dB SPL(FF) (ISO 389-8)
% for 250, 500, 1k, 2k, 4k, 6k, 8k Hz
% value for 6k was interpolated from 5k and 6.3k 
setup.Gf_Gc  = [-4.5 -2.5 -3.5 -5.0 -13.0 -11.8  -8.5];


% signal definition
% add signal name and the correction value for calibration for left and 
% right ear relative to the calibration value for 1 kHz (see addon_ACALOS_readme.txt
% "Calibration"). First calibrate at 1 kHz before editing these values.
setup.signalnames = {...
    % narrow band measurements in dB HL
    'lnn250_1_50.wav','-8.0','-8.0';...     %1
    'lnn500_1_50.wav','-1.75','-1.75';...   %2
    'lnn1000_1_50.wav','0','0';...          %3
    'lnn2000_1_50.wav','-3.25','-3.25';...  %4
    'lnn4000_1_50.wav','-7.5','-7.5';...    %5
    'lnn6000_1_50.wav','-13.0','-13.0';...  %6
    'lnn8000_1_50.wav','0','0';...          %7
    };

% windows
setup.hannlen = round(0.05*def.samplerate);
setup.window = hannfl(def.intervallen,setup.hannlen,setup.hannlen);

% eof