% ACALOS_init - init script for ACALOS procedure
% Version 1.30.0, last modified 11.04.2013 16:36

% ------------------------------------------------------------------------------
%  Adaptive Categorical Loudness Scaling Procedure for AFC for Mathwork's MATLAB
% 
%  Author(s): Stephan Ewert, Dirk Oetting
% 
%  Copyright (c) 2013-2014, Stephan Ewert, Dirk Oetting
%  All rights reserved.
% 
%  This work is licensed under the 
%  Creative Commons Attribution-NonCommercial-NoDerivs 4.0 International License (CC BY-NC-ND 4.0). 
%  To view a copy of this license, visit
%  http://creativecommons.org/licenses/by-nc-nd/4.0/ or send a letter to Creative
%  Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.
% ------------------------------------------------------------------------------

% add procedure specific path if required paths
addpath([fileparts(which(mfilename)), filesep, 'ACALOS'])

% some splash screen
ACALOS_splashscreen( 'open' );

% change save function to method specific default if default save function is requested
if ( strcmp( def.savefcn, 'default' ) )
    def.savefcn = 'ACALOS_loudfit';
end

for (i=1:def.interleavenum)

    % initialize starting value for all interleaved tracks
    work.expvarnext{i} = def.startvar{i};				% pre buffer (cell array) for expvaract, copied to expvaract in afc_interleave


    % add procedure specific entries to structure work
    % work.ACALOS_PhaseCounter{i} = 0;								% phase of the procedure, 0 = finding initial level in audible range, 1 = up-down trace, 2 = estimation and presentation
    % work.ACALOS_UpDownTrack{i} = 0;									% 0 = up, 1 = down (during PhaseCounter == 1)
    % work.ACALOS_DownTrackMode{i} = 0;								% 0 = down, 1 = up after having reached inaudible
    % work.ACALOS_UpDownTrackTerminated{i} = [0 0];		% traces terminated?
    
    % add procedure specific entries to structure work
    work.ACALOS{i} = struct;												% initialize
   	work.ACALOS{i}.new_level = work.expvarnext{i};	% updated by ACALOS level control, initialized with start level
    work.ACALOS{i}.level_history = work.expvarnext{i}; % history of presentation levels
    work.ACALOS{i}.CU_response = [];										% response history
    work.ACALOS{i}.up_flag = [0];
    work.ACALOS{i}.down_flag = [0];
    work.ACALOS{i}.phase = 1;
    work.ACALOS{i}.finished = false;
    work.ACALOS{i}.failed = false;
    work.ACALOS{i}.iteration_phase3 = 0;
    work.ACALOS{i}.useMeasuredCU_phase3 = false;			% true in OMA 2013
    work.ACALOS{i}.levels_phase3 = [];
    
    % inherit some settings from experiment configuration to ACALOS control struct
    work.ACALOS{i}.iterations = def.ACALOS_Iterations;
    % maximal presentation level, only use values that can be reach from
    % the first level in 5 dB steps
    work.ACALOS{i}.maximal_presentation_level = def.maxvar;
    work.ACALOS{i}.L_max = def.maxvar;
    % minimal presentation level.
    work.ACALOS{i}.minimal_presentation_level = def.minvar;
    
    work.ACALOS{i}.randomizeRangeEstimation = def.ACALOS_randomizeRangeEstimation;
    work.ACALOS{i}.levelRounding = def.ACALOS_levelRounding;
    
end

% eof
