% ACALOS_loudfit_savefcn - custom save function for ACALOS procedure
% Version 1.40.0, last modified 22.01.2013 09:36

% ------------------------------------------------------------------------------
%  Adaptive Categorical Loudness Scaling Procedure for AFC for Mathwork's MATLAB
% 
%  Author(s): Stephan Ewert, Dirk Oetting
% 
%  Copyright (c) 2013-2014, Stephan Ewert, Dirk Oetting
%  All rights reserved.
% 
%  This work is licensed under the 
%  Creative Commons Attribution-NonCommercial-NoDerivs 4.0 International License (CC BY-NC-ND 4.0). 
%  To view a copy of this license, visit
%  http://creativecommons.org/licenses/by-nc-nd/4.0/ or send a letter to Creative
%  Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.
% ------------------------------------------------------------------------------

function ACALOS_loudfit_savefcn

global def
global work

diary off;

str=[def.result_path work.filename];

%%%%%%%%% build headerline %%%%%%%%
if def.interleaved > 0
   headerl = '% track#';
else
   headerl = '%';
end
for i = 1:def.expparnum
   eval(['parunit = def.exppar' num2str(i) 'unit;']);
   headerl = [headerl '   exppar' num2str(i) '[' parunit ']'];
end
headerl = [headerl '   lcut[' def.expvarunit ']   mlow[CU/dB]   mhigh[CU/dB]'];
%%%%%%%% end headerline %%%%%%%%%


% cycle interleaved tracks
for i = 1:def.interleavenum

    % catch failed tracks
    if work.expvarrev{i} == 0.12345678;

        res{i}=[0.12345678, 0.12345678, 0.12345678];

    else

        % prepare level and response (CU) as alternating vector as required by the fit function
        dataLoudFit = [work.expvar{i}; work.answer{i}];
        dataLoudFit = reshape(dataLoudFit, 1, []);

        % apply fit to data, returns structure [fit.lcut, fit.mlow, fit.mhigh]
        % SE catch failed fits 24.07.2013, indicated by -1 -1 -1
        %
        % select 'BY' for fitting function of Brand and Hohmann (2002) and
        % BTUX for improved fitting function by Oetting et al. (2014)
        select_fitting_function = 'BTUX';
        switch upper(select_fitting_function)
            case 'BY'
                % fitting method of Brand and Hohmann (2002)
                fit = fit_loudness_function(dataLoudFit,'BY');
                res{i}=[fit(1), fit(2), fit(3)];
            case {'BX','BTX','BTUX','BTUY','BTPX'}
                % fitting method of Oetting et al. (2014) with optional
                % threshold estimation and UCL estimation if not enough
                % reponse were measured in the upper loudness domain
                fitparams = fit_loudness_function(dataLoudFit,select_fitting_function);

                % calculate parameters as for the the BX fitting function
                res{i}=fitparams;
        end
        

    end

    r='   %8.8f   %8.8f   %8.8f';


end


ex = exist([str '.dat']);

if ex == 0
   %dat=['% exppar[' def.exppar1unit ']   expvar[' def.expvarunit ']'];
   fid=fopen([str '.dat'],'w');
   fprintf(fid,['%s\n'],headerl);
   for k=1:def.interleavenum
      if def.interleaved > 0
         fprintf(fid,'%i',k);
      end
   	for i=1:def.expparnum
      	eval(['tmp = work.int_exppar' num2str(i) '{' num2str(k) '};']);
      	if def.exppartype(i) == 0
         	fprintf(fid,['   %8.8f'],tmp);
      	else
         	fprintf(fid,['   %s'],tmp);
      	end
      end
      fprintf(fid,[r '\n'],res{k});
   end
   
   
   %fprintf(fid,['%8.8f' r '\n'],res);
	fclose(fid);
else
   fid=fopen([str '.dat'],'a');
   for k=1:def.interleavenum
      if def.interleaved > 0
         fprintf(fid,'%i',k);
      end
   	for i=1:def.expparnum
      	eval(['tmp = work.int_exppar' num2str(i) '{' num2str(k) '};']);
      	if def.exppartype(i) == 0
         	fprintf(fid,['   %8.8f'],tmp);
      	else
         	fprintf(fid,['   %s'],tmp);
      	end
      end
      fprintf(fid,[r '\n'],res{k});
   end

   
   
   
   %	fprintf(fid,['%8.8f' r '\n'],res);
	fclose(fid);
end

if def.debug == 1
save([str '.mat'], 'work'); 
end

% eof