% ACALOS_procedure - custom measurement procedure
% Version 1.40.0, last modified 29.07.2014 13:43
%
% input:
% answer - holds the input passed to afc_control by _pressfcn (in most cases the number of the button pressed)
%
% must update:
% work.expvarnext{work.pvind} - updated value of experimental variable
% work.stepnum{work.pvind} - history of steps, append last step number
% work.trackfinished{work.pvind}
% work.finishedcount

% ------------------------------------------------------------------------------
%  Adaptive Categorical Loudness Scaling Procedure for AFC for Mathwork's MATLAB
% 
%  Author(s): Stephan Ewert, Dirk Oetting
% 
%  Copyright (c) 2013-2014, Stephan Ewert, Dirk Oetting
%  All rights reserved.
% 
%  This work is licensed under the 
%  Creative Commons Attribution-NonCommercial-NoDerivs 4.0 International License (CC BY-NC-ND 4.0). 
%  To view a copy of this license, visit
%  http://creativecommons.org/licenses/by-nc-nd/4.0/ or send a letter to Creative
%  Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.
% ------------------------------------------------------------------------------


% example for ACALOS

% retrieve finished state from ACALOS, was already set last function call
if work.ACALOS{work.pvind}.finished
    finished = 1;
else

    finished = 0;

    % append response to struct
    work.ACALOS{work.pvind}.CU_response = [work.ACALOS{work.pvind}.CU_response answer];

    % ACALOS level control
    work.ACALOS{work.pvind} = ACALOS_level_control_bh_2002(work.ACALOS{work.pvind});

    % update expvarnext
    work.expvarnext{work.pvind} = work.ACALOS{work.pvind}.new_level;




    % Sanity check lower and upper bounds
    if work.expvarnext{work.pvind} > def.maxvar
        work.expvarnext{work.pvind} = def.maxvar;
        work.minmaxcount{work.pvind} = work.minmaxcount{work.pvind} + 1;
        if ( work.predict == 0 & def.afcwinEnable > 0 )
            feval(def.afcwin, 'maxvar');
        end
    elseif work.expvarnext{work.pvind} < def.minvar
        work.expvarnext{work.pvind} = def.minvar;
        work.minmaxcount{work.pvind} = work.minmaxcount{work.pvind} + 1;
        if ( work.predict == 0 & def.afcwinEnable > 0 )
            feval(def.afcwin, 'minvar');
        end
    end
end


% If we are in prediction state the procedure is not actually run. Time to leave.
if work.predict == 1
    return;
end


%----------------------- experimental run -----------------------------
%%%%%%% track already terminated but was called again (due to interleaving) %%%%%%%%
if work.trackfinished{work.pvind}==1	% undo changes in work
    %disp('kdgfsdlkgjsdgjsdgjsdg');

    % changed 4/17/01 undo only if tracks are not to be continued
    if ~def.holdtrack
        work = worksave;
    else		% otherwise fake continue
        work.stepnum{work.pvind}=[work.stepnum{work.pvind} max(work.stepnum{work.pvind})+1];
    end
else
    %%%%%%% track termination on minmaxcount %%%%%%%%%
    if ( (work.minmaxcount{work.pvind} * def.terminate >= def.endstop) | work.ACALOS{work.pvind}.failed )

        if ~def.allterminate
            work.trackfinished{work.pvind} = 1;						% was work.terminate before
            work.finishedcount = work.finishedcount + 1;

            % changed 4/17/01 remove track if hold off
            if ~def.holdtrack
                work.removetrack = work.pvind;
            else		% otherwise fake continue
                work.stepnum{work.pvind}=[work.stepnum{work.pvind} max(work.stepnum{work.pvind})+1];
            end

            %disp('track skipped');
            work.expvarrev{work.pvind} = 0.12345678;

            %afc_result;					% moved to main
            %work.writeresult =1;

            % else part from allterminate
        else
            for i = 1:def.interleavenum
                work.trackfinished{i} = 1;                                         % was work.terminate before
                work.finishedcount = work.finishedcount + 1;
                work.removetrack = i;
                %disp('track skipped');
                work.expvarrev{i} = 0.12345678;
            end
        end


        %%%%%%% track termination because ACALOS is finished %%%%%%%%%
    elseif finished
        work.trackfinished{work.pvind}=1;						% end of threshold run
        work.finishedcount = work.finishedcount + 1;

        % changed 4/17/01
        work.reachedendreversalnum{work.pvind} = work.stepnum{work.pvind}(end);

        % changed 4/17/01 remove track if hold off
        if ~def.holdtrack
            work.removetrack = work.pvind;
        else		% otherwise fake continue
            work.stepnum{work.pvind}=[work.stepnum{work.pvind} max(work.stepnum{work.pvind})+1];
        end

        %afc_result;					% moved to main
        %work.writeresult =1;

        %%%%%%% go on %%%%%%%%
    else
        work.stepnum{work.pvind}=[work.stepnum{work.pvind} max(work.stepnum{work.pvind})+1];
        %set(h,'Userdata',-1);

    end
end % if already terminated



% eof
