% ACALOS_proto - custom protocol file for ACALOS procedure
% Version 1.30.0, last modified 16.04.2013 09:36

% ------------------------------------------------------------------------------
%  Adaptive Categorical Loudness Scaling Procedure for AFC for Mathwork's MATLAB
% 
%  Author(s): Stephan Ewert, Dirk Oetting
% 
%  Copyright (c) 2013-2014, Stephan Ewert, Dirk Oetting
%  All rights reserved.
% 
%  This work is licensed under the 
%  Creative Commons Attribution-NonCommercial-NoDerivs 4.0 International License (CC BY-NC-ND 4.0). 
%  To view a copy of this license, visit
%  http://creativecommons.org/licenses/by-nc-nd/4.0/ or send a letter to Creative
%  Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.
% ------------------------------------------------------------------------------

% The protocol file is opened and closed in afc_proto.m,
% here only the writing of the procedure-specific protocol entry is performed.
% The protocol entry must follow AFC's protocol file conventions

% write the header for next entry
fprintf(fid,['%s\n'],'%');
if def.interleaved == 0
    fprintf(fid,['%s\n'],['% new entry (date/experiment/' parstr 'response/' varstr 'Lcut mLow mHigh/procedure)']);
else
    fprintf(fid,['%s\n'],['% new entry (date/experiment/' parstr 'response/' varstr 'order/Lcut mLow mHigh/procedure)']);
end

% write date/time and current experiment file name
fprintf(fid,['%s\n'],dateTime);
fprintf(fid,['%s\n'],expFileName);

% prepare and write the data for each track (just one track if not interleaved, def.interleavenum = 1)
for i = 1:def.interleavenum

    % prepare the data for saving
    res = int2str(work.answer{i});
    expvar = num2str(work.expvar{i},'%8.8f   ');

    % store the presentation order of stimuli
    presentationOrder = int2str(work.presentationOrder{i});

    % prepare level and response (CU) as alternating vector as required by the fit function
    dataLoudFit = [work.expvar{i}; work.answer{i}];
    dataLoudFit = reshape(dataLoudFit, 1, []);

    % catch failed tracks
    if work.expvarrev{i} == 0.12345678;

        loudfit = num2str([0.12345678, 0.12345678, 0.12345678],'%8.8f   %8.8f   %8.8f');

    else
        select_fitting_function = 'BTUX';
        switch lower(select_fitting_function)
            case 'by'
                % fitting method of Brand and Hohmann (2002)
                fit = fit_loudness_function(dataLoudFit,'BY');
                loudfit = num2str([fit(1), fit(2), fit(3)],'%8.8f   %8.8f   %8.8f');                    
            case 'btux'
                % fitting method of Oetting et al. (2014) with
                % threshold estimation and UCL estimation if not enough
                % reponse were measured in the upper loudness domain
                fitparams = fit_loudness_function(dataLoudFit,'BTUX');

                % calculate parameters as for the the BX fitting function
                loudfit = num2str(fitparams,'%8.8f   %8.8f   %8.8f');                    
                
        end
    end

    %%%%%%%%%%% start writing %%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % write track number if interleaved
    if def.interleaved > 0
        fprintf(fid,['%s\n'],['% track ' num2str(i)]);
    end

    % current values for exppar(s)
    for k = 1:def.expparnum
        eval(['expparStr = num2str(work.int_exppar' num2str(k) '{i}, ''%8.8f'' );']);
        fprintf(fid,['%s\n'], expparStr );
    end

    % selected data as defined above
    fprintf(fid,['%s\n'],res);
    fprintf(fid,['%s\n'],expvar);
    if def.interleaved > 0
        fprintf(fid,['%s\n'],presentationOrder);
    end
    fprintf(fid,['%s\n'],loudfit);

    % append name of measurement procedure
    fprintf(fid,['%s\n'], def.measurementProcedure );
end

% eof
